PlanError

Enum PlanError 

pub enum PlanError {
    UnknownImplementation(String),
    UnknownInstance(String),
    UnknownCoLocation(String),
}
Plan-Validation-Fehler.

Variants



UnknownImplementation(String)

Instance referenziert eine Implementation, die nicht im Plan existiert.



UnknownInstance(String)

Connection referenziert eine Instance, die nicht im Plan existiert.



UnknownCoLocation(String)

Co-Location-Liste verweist auf eine Instance, die nicht im Plan existiert.